@@ -3,6 +3,8 @@ import os
 from flask import Blueprint
 from flask.ext.mako import render_template
 
+from hflossk.util import app_path
+
 
 homework = Blueprint('homework', __name__, template_folder='templates')
 lectures = Blueprint('lectures', __name__, template_folder='templates')
@@ -13,9 +15,8 @@ quizzes = Blueprint('quizzes', __name__, template_folder='templates')
 @homework.route('/<page>')
 def display_homework(page):
     if page == 'index':
-        hws = os.listdir(os.path.join(os.getcwd(), 'static', 'hw'))
-        hws.extend(os.listdir(os.path.join(os.getcwd(),
-                                           'templates', 'hw')))
+        hws = os.listdir(app_path('static', 'hw'))
+        hws.extend(os.listdir(app_path('templates', 'hw')))
         hws = [hw for hw in sorted(hws) if not hw == "index.mak"]
     else:
         hws = None
@@ -27,8 +28,7 @@ def display_homework(page):
 @lectures.route('/<page>')
 def display_lecture(page):
     if page == 'index':
-        lecture_notes = os.listdir(os.path.join(os.getcwd(),
-                                                'templates', 'lectures'))
+        lecture_notes = os.listdir(app_path('templates', 'lectures'))
         lecture_notes = [note for note in sorted(lecture_notes)
                          if not note == "index.mak"]
     else:
