@@ -19,24 +19,12 @@ def cli():
 @cli.command()
 def run():
     from hflossk.site import app
-    app.static_folder = os.path.join(os.getcwd(), 'static')
-    app.templates_folder = os.path.join(os.getcwd(), 'templates')
     app.run(
         debug=True,
         threaded=True,
     )
 
 
-@cli.command()
-def openshift():
-    from hflossk.site import app
-    host = os.environ['OPENSHIFT_PYTHON_IP']
-    port = int(os.environ['OPENSHIFT_PYTHON_PORT'])
-    http_server = HTTPServer(WSGIContainer(app))
-    http_server.listen(port, address=host)
-    IOLoop.instance().start()
-
-
 @cli.command()
 def new():
     # \u2714 is a check mark
@@ -75,7 +63,7 @@ def new():
 
 @cli.command()
 def version():
-    print("You are using hflossk version 0.5.1")
+    print("You are using hflossk version 0.5.2")
     print("Get more information at "
           "https://github.com/decause/hflossk")
 
